@@ -28,6 +28,8 @@ class Produto(core.models.Log):
     largura_ecommerce = models.DecimalField(max_digits=14, decimal_places=2, null=True)
     profundidade_ecommerce = models.DecimalField(max_digits=14, decimal_places=2, null=True)
     peso_ecommerce = models.DecimalField(max_digits=14, decimal_places=2, null=True)
+    qtd_min_venda_ecommerce = models.IntegerField(null=True, default=1)
+    qtd_max_venda_ecommerce = models.IntegerField(null=True)
 
     is_retencao_receita = models.BooleanField(default=False, null=True)
     is_venda_controlada = models.BooleanField(default=False, null=True)
@@ -268,3 +270,22 @@ class DescontoRelacao(core.models.Log):
     class Meta(core.models.Log.Meta):
         abstract = False
         db_table = 'produto_descontorelacao'
+
+
+class Estoque(core.models.Log):
+    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True)
+    quantidade = models.IntegerField(null=True)
+    cd_filial = models.ForeignKey('filial.Filial', on_delete=models.DO_NOTHING, null=True)
+
+    class Meta(core.models.Log.Meta):
+        abstract = False
+        db_table = 'produto_estoque'
+
+
+class EstoqueRede(core.models.Log):
+    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True)
+    quantidade = models.IntegerField(null=True)
+
+    class Meta(core.models.Log.Meta):
+        abstract = False
+        db_table = 'produto_estoquerede'
